Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(245)

Unified Diff: content/browser/browser_main_loop.cc

Issue 2590413003: Update TaskTraits in browser_main_loop.cc. (Closed)
Patch Set: Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/browser_main_loop.cc
diff --git a/content/browser/browser_main_loop.cc b/content/browser/browser_main_loop.cc
index aed3789f7230625bd929d0c4a7decd3adfa30f0e..cc10db40fa88bb425a9b95f581cefe6179ed49be 100644
--- a/content/browser/browser_main_loop.cc
+++ b/content/browser/browser_main_loop.cc
@@ -1011,10 +1011,11 @@ int BrowserMainLoop::CreateThreads() {
// Otherwise this thread ID will be backed by a SingleThreadTaskRunner using
// |non_ui_non_io_task_runner_traits| (which can be augmented below).
// TODO(gab): Existing non-UI/non-IO BrowserThreads allow waiting so the
// initial redirection will as well but they probably don't need to.
gab 2016/12/21 16:16:57 This TODO was meant to flag WithWait() being overk
fdoray 2016/12/21 16:26:19 Done.
base::TaskTraits non_ui_non_io_task_runner_traits =
- base::TaskTraits().WithFileIO().WithWait();
+ base::TaskTraits().MayBlock().WithSyncPrimitives();
switch (thread_id) {
case BrowserThread::DB:
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -1011,10 +1011,11 @@ int BrowserMainLoop::CreateThreads() {
// Otherwise this thread ID will be backed by a SingleThreadTaskRunner using
// |non_ui_non_io_task_runner_traits| (which can be augmented below).
- // TODO(gab): Existing non-UI/non-IO BrowserThreads allow waiting so the
- // initial redirection will as well but they probably don't need to.
+ // TODO(gab): Existing non-UI/non-IO BrowserThreads allow blocking and sync
+ // primitives so the initial redirection will as well but they probably
+ // don't need to.
gab 2016/12/21 16:16:57 This TODO was meant to flag WithWait() being overk
fdoray 2016/12/21 16:26:19 Done.

Powered by Google App Engine
This is Rietveld 408576698